@@ -2,6 +2,21 @@ from gitlabform.gitlab.core import GitLabCore
 
 
 class GitLabMembers(GitLabCore):
+    def get_project_members(self, project_and_group_name, all=False):
+        url_template = "projects/%s/members"
+        if all:
+            url_template += "/all"
+
+        return self._make_requests_to_api(
+            url_template, project_and_group_name, paginated=True
+        )
+
+    def get_shared_with_groups(self, project_and_group_name):
+        # a dict with groups that this project has been shared with
+        return self._make_requests_to_api("projects/%s", project_and_group_name)[
+            "shared_with_groups"
+        ]
+
     def add_member_to_project(
         self, project_and_group_name, username, access_level, expires_at=None
     ):
@@ -33,6 +48,19 @@ class GitLabMembers(GitLabCore):
 
         return self._make_requests_to_api(url_template, group_name, paginated=True)
 
+    def get_members_from_project(self, project_and_group_name):
+        members = self._make_requests_to_api(
+            "projects/%s/members", project_and_group_name
+        )
+        # it will return {username1: {...api info about username1...}, username2: {...}}
+        # otherwise it can get very long to iterate when checking if a user
+        # is already in the project if there are a lot of users to check
+        final_members = {}
+        for member in members:
+            final_members[member["username"]] = member
+
+        return final_members
+
     def add_member_to_group(self, group_name, username, access_level, expires_at=None):
         data = {"user_id": self._get_user_id(username), "expires_at": expires_at}
         if access_level is not None:
